@@ -1,25 +1,30 @@
+"""Interactive Dialog wizards to gather User Input for Context variables."""
+
 import json
 import logging
 import typing as t
+from pathlib import Path
+
+from jinja2 import Environment, FileSystemLoader
+
+from cookiecutter_python.handle.interactive_cli_pipeline import (
+    InteractiveDialogsPipeline,
+)
+
+
+logger = logging.getLogger(__name__)
+
+my_dir = Path(__file__).parent.absolute()
 
 
 GivenInterpreters = t.Mapping[str, t.Sequence[str]]
 
-logger = logging.getLogger(__name__)
-
 
 def parse_context(config_file: str):
     """Render Context on demand, using cookiecutter.json and optional config file."""
-    from pathlib import Path
-
-    my_dir = Path(__file__).parent.absolute()
 
     # use whatever way cookiecutter uses to render the cookiecutter.json
-    # cookie uses Jinja2
-
-    from jinja2 import Environment, FileSystemLoader
-
-    # render file
+    # cookiecutter uses Jinja2 to render files
     env = Environment(
         loader=FileSystemLoader(str(my_dir / '..')),
         extensions=['jinja2_time.TimeExtension'],  # shipped with cookiecutter 1.7
@@ -66,57 +71,73 @@ def parse_context(config_file: str):
         **{k: v[0] for k, v in choices.items() if k not in user_default_context},
     )
 
-    from cookiecutter_python.handle.interactive_cli_pipeline import (
-        InteractiveDialogsPipeline,
-    )
+    # Render cookiecutter.json again with context to resolve derived fields
+    # This ensures derived fields like pkg_name get computed properly
+    template = env.get_template('cookiecutter.json')
+    rendered_with_context = template.render({'cookiecutter': context_defaults})
+    resolved_cook_json: t.Mapping[str, t.Any] = json.loads(rendered_with_context)
+
+    # Update context_defaults with resolved derived fields, but preserve user config values
+    for key, value in resolved_cook_json.items():
+        # Only update if the key wasn't explicitly provided by user
+        if key not in user_default_context:
+            context_defaults[key] = value
 
     pipe = InteractiveDialogsPipeline()
 
-    # assert choices['rtd_python_version'] == [], f"DEBUG: {choices['rtd_python_version']}"
-    res = pipe.process(
-        [
-            {
-                "project_name": context_defaults['project_name'],
-                "project_type": {
-                    'default': context_defaults['project_type'],
-                    'choices': choices['project_type'],
-                },
-                "full_name": context_defaults['full_name'],
-                "author_email": context_defaults['author_email'],
-                "github_username": context_defaults['github_username'],
-                "project_short_description": context_defaults[
-                    'project_short_description'
-                ],
-                # "release_date": context_defaults['release_date'],
-                # "year": context_defaults['year'],
-                "version": context_defaults['version'],
-                "initialize_git_repo": {
-                    'default': context_defaults['initialize_git_repo'],
-                    'choices': choices['initialize_git_repo'],
-                },
-                "supported-interpreters": {
-                    # 'default': context_defaults['initialize_git_repo'],
-                    'choices': [
-                        (choice, True)
-                        for choice in user_interpreters.get(
-                            'supported-interpreters',
-                            ["3.6", "3.7", "3.8", "3.9", "3.10", "3.11"],
-                        )
-                    ],
-                },
-                "docs_builder": {
-                    'default': context_defaults['docs_builder'],
-                    'choices': choices['docs_builder'],
-                },
-                "rtd_python_version": {
-                    'default': context_defaults['rtd_python_version'],
-                    'choices': choices['rtd_python_version'],
-                },
-                "cicd": {
-                    'default': context_defaults['cicd'],
-                    'choices': choices['cicd'],
-                },
+    # Build the context dynamically to include all fields
+    interactive_context = {}
+
+    # Simple fields (no choices)
+    simple_fields = [
+        'project_name',
+        'project_slug',
+        'pkg_name',
+        'repo_name',
+        'readthedocs_project_slug',
+        'docker_image',
+        'full_name',
+        'author',
+        'author_email',
+        'github_username',
+        'project_short_description',
+        'pypi_subtitle',
+        'version',
+    ]
+
+    for field in simple_fields:
+        if field in context_defaults:
+            interactive_context[field] = context_defaults[field]
+
+    # Choice fields (with options)
+    choice_fields = [
+        'project_type',
+        'initialize_git_repo',
+        'docs_builder',
+        'rtd_python_version',
+        'cicd',
+        # Include Grafana, Loki stack no/yes
+        'include_observability',  # ["no", "yes"]
+    ]
+
+    for field in choice_fields:
+        if field in choices:
+            interactive_context[field] = {
+                'default': context_defaults[field],
+                'choices': choices[field],
             }
-        ]
-    )
+
+    # Special handling for interpreters
+    interactive_context["supported-interpreters"] = {
+        'choices': [
+            (choice, True)
+            for choice in user_interpreters.get(
+                'supported-interpreters',
+                ["3.6", "3.7", "3.8", "3.9", "3.10", "3.11"],
+            )
+        ],
+    }
+
+    # assert choices['rtd_python_version'] == [], f"DEBUG: {choices['rtd_python_version']}"
+    res = pipe.process([interactive_context])
     return res
